<?php

namespace Drupal\image_derivative_token;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\DependencyInjection\DependencySerializationTrait;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides alterations to the image style edit form.
 */
class ImageStyleEditFormAlter implements ContainerInjectionInterface {

  use DependencySerializationTrait;
  use StringTranslationTrait;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * Constructs an ImageStyleEditFormAlter object.
   *
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   */
  public function __construct(AccountInterface $current_user) {
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user')
    );
  }

  /**
   * Alter an image style edit form.
   *
   * @param array $form
   *   The form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param string $form_id
   *   The form ID.
   */
  public function alter(array &$form, FormStateInterface $form_state, $form_id) {
    /** @var \Drupal\image\Form\ImageStyleEditForm $form_object */
    $form_object = $form_state->getFormObject();

    /** @var \Drupal\image\ImageStyleInterface $image_style */
    $image_style = $form_object->getEntity();

    // Add a third-party setting to allow image derivatives to be generated
    // without a token for this image style.
    $form['third_party_settings']['image_derivative_token']['allow_insecure_derivatives'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow insecure derivatives'),
      '#description' => $this->t('If checked, image derivatives will be able to be generated without a token for this image style.'),
      '#default_value' => $image_style->getThirdPartySetting('image_derivative_token', 'allow_insecure_derivatives', FALSE),
    ];

    // Add a third-party setting to suppress the image token when rendering
    // an image derivative.
    $form['third_party_settings']['image_derivative_token']['suppress_itok_output'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Suppress image token output'),
      '#description' => $this->t('If selected, an image token will not be output for image derivates generated by this image style.'),
      '#default_value' => $image_style->getThirdPartySetting('image_derivative_token', 'suppress_itok_output', FALSE),
    ];

    // Hide third-party settings if the current user does not have the proper
    // permission.
    if (!$this->currentUser->hasPermission('administer image derivative token settings')) {
      $form['third_party_settings']['image_derivative_token']['#access'] = FALSE;
    }
  }

}
